mdbr bundles the Northwind Access database in inst/extdata. This helper returns its path, or lists bundled examples when path = NULL.

mdb_example(path = "nwind.mdb")

Arguments

path

Name of the bundled Microsoft Access file, or NULL to list available examples.

Value

A character string with the full path to the bundled example file.

Examples

mdb_example()
#> [1] "/home/runner/work/_temp/Library/mdbr/extdata/nwind.mdb"