| mdb_prop | R Documentation |
mdb-prop retrieves properties for one or more objects in an MDB database.
name is the name of the table, query, or other object.
propcol is the name of the MSysObjects column containing properties and
defaults to LvProp.
mdb_prop(
path,
name = NULL,
propcol = "LvProp",
version = FALSE,
as_list = TRUE
)
path |
Path to |
name |
Object name ( |
propcol |
Property column name. Defaults to |
version |
Logical; when |
as_list |
Logical; defaults to |
A named list with one entry per element of name. Each entry is
itself a named list of named character vectors, one per property block
(e.g. "(none)" for table-level properties, or a column/field name).
Access individual values with p[["Orders"]][["(none)"]]["Description"].
db <- mdbr:::.mdb_example_nwind_path()
if (nzchar(db)) {
p <- mdb_prop(db, "Orders")
p[["Orders"]][["(none)"]]["Description"]
p2 <- mdb_prop(db, c("Orders", "Orders Qry"))
}
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.