| mdb_sql | R Documentation |
mdb-sql is a utility program distributed with MDB Tools.
It allows querying of an MDB database using a limited SQL subset language.
The supported SQL is intentionally small: single-table queries, no aggregates,
and limited WHERE support.
mdb_sql(
path,
statement = NULL,
no_header = FALSE,
no_footer = FALSE,
no_pretty_print = FALSE,
delimiter = "\t",
input = NULL,
output = NULL,
as_text = FALSE
)
path |
Path to |
statement |
SQL statement text. |
no_header |
Logical, equivalent to |
no_footer |
Logical, equivalent to |
no_pretty_print |
Logical, equivalent to |
delimiter |
Delimiter equivalent to |
input |
Input file equivalent to |
output |
Output file equivalent to |
as_text |
Logical; when |
In addition to single statements, this wrapper accepts input files similar
to mdb-sql -i file, strips go batch terminators, and executes the script
one statement at a time.
data.frame by default, or character scalar in text mode.
db <- mdbr:::.mdb_example_nwind_path()
if (nzchar(db)) {
mdb_sql(db, "SELECT [ProductID], [ProductName] FROM [Products] LIMIT 3;")
}
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.