mdbr bundles the Northwind Access database in inst/extdata. This helper
returns its path, or lists bundled examples when path = NULL.
mdb_example(path = "nwind.mdb")A character string with the full path to the bundled example file.
mdb_example()
#> [1] "/home/runner/work/_temp/Library/mdbr/extdata/nwind.mdb"