mdbr comes bundled with a sample file from the nycflights13 package in its inst/extdata directory. This function make it easy to access.
mdb_example(path = "nycflights13.mdb")A character string with the full path to the bundled example file.
mdb_example()
#> [1] "/home/runner/work/_temp/Library/mdbr/extdata/nycflights13.mdb"