mdb_example: Get path to mdbr example

View source: R/example.R

mdb_exampleR Documentation

Get path to mdbr example

Description

mdbr comes bundled with a sample file from the nycflights13 package in its inst/extdata directory. This function make it easy to access.

Usage

mdb_example(path = "nycflights13.mdb")

Arguments

path

path to the Microsoft Access file.

Value

A character string with the full path to the bundled example file.

Examples

mdb_example()

mdbr documentation built on May 28, 2026, 5:09 p.m.