mdb-ver will return a single line of output corresponding to the program that produced the file: JET3 (for files produced by Access 97), JET4 (Access 2000, XP and 2003), ACE12 (Access 2007), ACE14 (Access 2010), ACE15 (Access 2013), or ACE16 (Access 2016).

mdb_ver(path = NULL, version = FALSE)

Arguments

path

Optional database path. When omitted, the wrapper returns the mdbtools package version for backward compatibility.

version

Logical, equivalent to -M/--version.

Value

Single character string with file format or mdbtools version.

Examples

mdb_ver()
#> [1] "mdbtools v1.0.1"
db <- mdbr:::.mdb_example_nwind_path()
if (nzchar(db)) {
  mdb_ver(db)
}