| mdb_ver | R Documentation |
mdb-ver will return a single line of output corresponding to the program
that produced the file: JET3 (for files produced by Access 97), JET4
(Access 2000, XP and 2003), ACE12 (Access 2007), ACE14 (Access 2010),
ACE15 (Access 2013), or ACE16 (Access 2016).
mdb_ver(path = NULL, version = FALSE)
path |
Optional database path. When omitted, the wrapper returns the mdbtools package version for backward compatibility. |
version |
Logical, equivalent to |
Single character string with file format or mdbtools version.
mdb_ver()
db <- mdbr:::.mdb_example_nwind_path()
if (nzchar(db)) {
mdb_ver(db)
}
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.